@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2002-2023 The Octave Project Developers
+// Copyright (C) 2002-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -880,6 +880,13 @@ may lead to a segfault.  As an alternative, consider constructing pattern
 searches that reduce the number of matches (e.g., by creatively using set
 complement), and then further processing the return variables (now reduced in
 size) with successive @code{regexp} searches.
+
+Octave's @code{regexp} implementation is based on the Perl Compatible
+Regular Expressions library (@url{https://www.pcre.org/}).  For a more
+comprehensive list of @code{regexp} operator syntax see the
+@url{https://www.pcre.org/current/doc/html/pcre2syntax.html,,
+"PCRE Syntax quick-reference summary"}.
+
 @seealso{regexpi, strfind, regexprep}
 @end deftypefn */)
 {
@@ -1163,7 +1170,7 @@ size) with successive @code{regexp} searches.
 %! assert (b, {"foo bar foo"});
 %!test
 %! [a, b] = regexp (str, "fx.", "match", "split", "once");
-%! assert (a, "");;
+%! assert (a, "");
 %! assert (b, "foo bar foo");
 
 %!shared str
