@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1998-2021 The Octave Project Developers
+// Copyright (C) 1998-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -45,7 +45,9 @@
 #include "ov-cx-sparse.h"
 #include "sparse-xpow.h"
 
-static inline int
+OCTAVE_BEGIN_NAMESPACE(octave)
+
+static inline bool
 xisint (double x)
 {
   return (octave::math::x_nint (x) == x
@@ -64,7 +66,11 @@ xpow (const SparseMatrix& a, double b)
   octave_idx_type nr = a.rows ();
   octave_idx_type nc = a.cols ();
 
-  if (nr == 0 || nc == 0 || nr != nc)
+  if (nr == 0 || nc == 0)
+    return SparseMatrix ();
+
+  // If we are here, A is not empty ==> A needs to be square.
+  if (nr != nc)
     error ("for A^b, A must be a square matrix.  Use .^ for elementwise power.");
 
   if (! xisint (b))
@@ -95,6 +101,9 @@ xpow (const SparseMatrix& a, double b)
           double rcond = 0.0;
           MatrixType mattyp (a);
 
+          // FIXME: This causes an error if the input sparse matrix is all-zeros.
+          // That behavior is inconsistent with A ^ b when A is a full all-zeros
+          // matrix, which just returns Inf of the same size with a warning.
           atmp = a.inverse (mattyp, info, rcond, 1);
 
           if (info == -1)
@@ -103,19 +112,58 @@ xpow (const SparseMatrix& a, double b)
       else
         atmp = a;
 
+      if (atmp.nnz () == 0)  // Fast return for all-zeros matrix
+        return atmp;
+
       SparseMatrix result (atmp);
 
       btmp--;
 
-      while (btmp > 0)
+      // There are two approaches to the actual exponentiation.
+      // Exponentiation by squaring uses only a logarithmic number
+      // of multiplications but the matrices it multiplies tend to be dense
+      // towards the end.
+      // Linear multiplication uses a linear number of multiplications
+      // but one of the matrices it uses will be as sparse as the original
+      // matrix.
+      //
+      // The time to multiply fixed-size matrices is strongly affected by their
+      // sparsity. Denser matrices take much longer to multiply together.
+      // See this URL for a worked-through example:
+      // https://octave.discourse.group/t/3216/4
+      //
+      // The tradeoff is between many fast multiplications or a few slow ones.
+      //
+      // Large exponents favor the squaring technique, and sparse matrices
+      // favor linear multiplication.
+      //
+      // We calculate a threshold based on the sparsity of the input
+      // and use squaring for exponents larger than that.
+      //
+      // FIXME: Improve this threshold calculation.
+
+      uint64_t sparsity = atmp.numel () / atmp.nnz (); // reciprocal of density
+      int threshold = (sparsity >= 1000) ? 40
+                      : (sparsity >=  100) ? 20
+                      : 3;
+
+      if (btmp > threshold) // use squaring technique
         {
-          if (btmp & 1)
+          while (btmp > 0)
+            {
+              if (btmp & 1)
+                result = result * atmp;
+
+              btmp >>= 1;
+
+              if (btmp > 0)
+                atmp = atmp * atmp;
+            }
+        }
+      else // use linear multiplication
+        {
+          for (int i = 0; i < btmp; i++)
             result = result * atmp;
-
-          btmp >>= 1;
-
-          if (btmp > 0)
-            atmp = atmp * atmp;
         }
 
       retval = result;
@@ -132,7 +180,11 @@ xpow (const SparseComplexMatrix& a, double b)
   octave_idx_type nr = a.rows ();
   octave_idx_type nc = a.cols ();
 
-  if (nr == 0 || nc == 0 || nr != nc)
+  if (nr == 0 || nc == 0)
+    return SparseMatrix ();
+
+  // If we are here, A is not empty ==> A needs to be square.
+  if (nr != nc)
     error ("for A^b, A must be a square matrix.  Use .^ for elementwise power.");
 
   if (! xisint (b))
@@ -171,19 +223,41 @@ xpow (const SparseComplexMatrix& a, double b)
       else
         atmp = a;
 
+      if (atmp.nnz () == 0)  // Fast return for all-zeros matrix
+        return atmp;
+
       SparseComplexMatrix result (atmp);
 
       btmp--;
 
-      while (btmp > 0)
+      // Select multiplication sequence based on sparsity of atmp.
+      // See the long comment in xpow (const SparseMatrix& a, double b)
+      // for more details.
+      //
+      // FIXME: Improve this threshold calculation.
+
+      uint64_t sparsity = atmp.numel () / atmp.nnz (); // reciprocal of density
+      int threshold = (sparsity >= 1000) ? 40
+                      : (sparsity >=  100) ? 20
+                      : 3;
+
+      if (btmp > threshold) // use squaring technique
         {
-          if (btmp & 1)
+          while (btmp > 0)
+            {
+              if (btmp & 1)
+                result = result * atmp;
+
+              btmp >>= 1;
+
+              if (btmp > 0)
+                atmp = atmp * atmp;
+            }
+        }
+      else // use linear multiplication
+        {
+          for (int i = 0; i < btmp; i++)
             result = result * atmp;
-
-          btmp >>= 1;
-
-          if (btmp > 0)
-            atmp = atmp * atmp;
         }
 
       retval = result;
@@ -242,6 +316,30 @@ scalar_xpow (const S& a, const SM& b)
 /*
 %!assert (sparse (2) .^ [3, 4], sparse ([8, 16]))
 %!assert <47775> (sparse (2i) .^ [3, 4], sparse ([-0-8i, 16]))
+
+%!test <*63080>
+%! Z = sparse ([]);
+%! A = sparse (zeros (0, 2));
+%! B = sparse (zeros (2, 0));
+%! assert (Z ^  1, Z);
+%! assert (Z ^  0, Z);
+%! assert (Z ^ -1, Z);
+%! assert (A ^  1, Z);
+%! assert (A ^  0, Z);
+%! assert (A ^ -1, Z);
+%! assert (B ^  1, Z);
+%! assert (B ^  0, Z);
+%! assert (B ^ -1, Z);
+
+%!test <*63080>
+%! A = sparse (zeros (2, 2));
+%! assert (A ^  1, A);
+%! assert (A ^  0, sparse (eye (2, 2)));
+
+%!test <63080>
+%! A = sparse (zeros (2, 2));
+%! assert (A ^ -1, sparse (inf (2, 2)));
+
 */
 
 // -*- 1 -*-
@@ -265,7 +363,7 @@ elem_xpow (double a, const SparseMatrix& b)
           for (octave_idx_type i = 0; i < nr; i++)
             {
               octave_quit ();
-              result(i, j) = std::pow (atmp, b(i,j));
+              result(i, j) = std::pow (atmp, b(i, j));
             }
         }
 
@@ -280,7 +378,7 @@ elem_xpow (double a, const SparseMatrix& b)
           for (octave_idx_type i = 0; i < nr; i++)
             {
               octave_quit ();
-              result(i, j) = std::pow (a, b(i,j));
+              result(i, j) = std::pow (a, b(i, j));
             }
         }
 
@@ -305,7 +403,7 @@ elem_xpow (double a, const SparseComplexMatrix& b)
       for (octave_idx_type i = 0; i < nr; i++)
         {
           octave_quit ();
-          result(i, j) = std::pow (atmp, b(i,j));
+          result(i, j) = std::pow (atmp, b(i, j));
         }
     }
 
@@ -468,7 +566,7 @@ done:
             {
               octave_quit ();
               result.xelem (a.ridx (i), j) = std::pow (a.data (i),
-                                                       b(a.ridx (i), j));
+                                             b(a.ridx (i), j));
             }
         }
       result.maybe_compress (true);
@@ -672,7 +770,7 @@ elem_xpow (const SparseComplexMatrix& a, const SparseMatrix& b)
 
           if (xisint (btmp))
             result.xelem (a.ridx (i), j) = std::pow (a.data (i),
-                                                     static_cast<int> (btmp));
+                                           static_cast<int> (btmp));
           else
             result.xelem (a.ridx (i), j) = std::pow (a.data (i), btmp);
         }
@@ -736,10 +834,13 @@ elem_xpow (const SparseComplexMatrix& a, const SparseComplexMatrix& b)
         {
           octave_quit ();
           result.xelem (a.ridx (i), j) = std::pow (a.data (i),
-                                                   b(a.ridx (i), j));
+                                         b(a.ridx (i), j));
         }
     }
   result.maybe_compress (true);
 
   return result;
 }
+
+
+OCTAVE_END_NAMESPACE(octave)
