@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 1996-2017 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2024 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -33,10 +36,12 @@ along with Octave; see the file COPYING.  If not, see
 #include "ov.h"
 #include "ovl.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // Date and time functions.
 
 static octave_scalar_map
-mk_tm_map (const octave::sys::base_tm& t)
+mk_tm_map (const sys::base_tm& t)
 {
   octave_scalar_map m;
 
@@ -63,7 +68,7 @@ intfield (const octave_scalar_map& m, const std::string& k, const char *who)
 
   octave_value v = m.getfield (k);
 
-  if (! v.is_empty ())
+  if (! v.isempty ())
     retval = v.xint_value ("%s: invalid TM_STRUCT argument", who);
 
   return retval;
@@ -76,16 +81,16 @@ stringfield (const octave_scalar_map& m, const std::string& k, const char *who)
 
   octave_value v = m.getfield (k);
 
-  if (! v.is_empty ())
+  if (! v.isempty ())
     retval = v.xstring_value ("%s: invalid TM_STRUCT argument", who);
 
   return retval;
 }
 
-static octave::sys::base_tm
+static sys::base_tm
 extract_tm (const octave_scalar_map& m, const char *who)
 {
-  octave::sys::base_tm tm;
+  sys::base_tm tm;
 
   tm.usec (intfield (m, "usec", who));
   tm.sec (intfield (m, "sec", who));
@@ -108,16 +113,17 @@ DEFUN (time, args, ,
 @deftypefn {} {@var{seconds} =} time ()
 Return the current time as the number of seconds since the epoch.
 
-The epoch is referenced to 00:00:00 CUT (Coordinated Universal Time) 1 Jan
-1970.  For example, on Monday February 17, 1997 at 07:15:06 CUT, the value
+The epoch is referenced to 00:00:00 UTC (Coordinated Universal Time) 1 Jan
+1970.  For example, on Monday February 17, 1997 at 07:15:06 UTC, the value
 returned by @code{time} was 856163706.
-@seealso{strftime, strptime, localtime, gmtime, mktime, now, date, clock, datenum, datestr, datevec, calendar, weekday}
+@seealso{strftime, strptime, localtime, gmtime, mktime, now, date, clock,
+datenum, datestr, datevec, calendar, weekday}
 @end deftypefn */)
 {
   if (args.length () != 0)
     print_usage ();
 
-  return ovl (octave::sys::time ());
+  return ovl (sys::time ());
 }
 
 /*
@@ -130,7 +136,7 @@ DEFUN (gmtime, args, ,
        doc: /* -*- texinfo -*-
 @deftypefn {} {@var{tm_struct} =} gmtime (@var{t})
 Given a value returned from @code{time}, or any non-negative integer,
-return a time structure corresponding to CUT (Coordinated Universal Time).
+return a time structure corresponding to UTC (Coordinated Universal Time).
 
 For example:
 
@@ -153,15 +159,16 @@ gmtime (time ())
         @}
 @end group
 @end example
-@seealso{strftime, strptime, localtime, mktime, time, now, date, clock, datenum, datestr, datevec, calendar, weekday}
+@seealso{strftime, strptime, localtime, mktime, time, now, date, clock, datenum,
+datestr, datevec, calendar, weekday}
 @end deftypefn */)
 {
-  if (args.length () != 1)
+  if (args.length () != 1 || args(0).numel () != 1)
     print_usage ();
 
   double tmp = args(0).double_value ();
 
-  return ovl (mk_tm_map (octave::sys::gmtime (tmp)));
+  return ovl (mk_tm_map (sys::gmtime (tmp)));
 }
 
 /*
@@ -208,15 +215,16 @@ localtime (time ())
         @}
 @end group
 @end example
-@seealso{strftime, strptime, gmtime, mktime, time, now, date, clock, datenum, datestr, datevec, calendar, weekday}
+@seealso{strftime, strptime, gmtime, mktime, time, now, date, clock, datenum,
+datestr, datevec, calendar, weekday}
 @end deftypefn */)
 {
-  if (args.length () != 1)
+  if (args.length () != 1 || args(0).numel () != 1)
     print_usage ();
 
   double tmp = args(0).double_value ();
 
-  return ovl (mk_tm_map (octave::sys::localtime (tmp)));
+  return ovl (mk_tm_map (sys::localtime (tmp)));
 }
 
 /*
@@ -252,7 +260,8 @@ mktime (localtime (time ()))
      @result{} 856163706
 @end group
 @end example
-@seealso{strftime, strptime, localtime, gmtime, time, now, date, clock, datenum, datestr, datevec, calendar, weekday}
+@seealso{strftime, strptime, localtime, gmtime, time, now, date, clock, datenum,
+datestr, datevec, calendar, weekday}
 @end deftypefn */)
 {
   if (args.length () != 1)
@@ -260,9 +269,9 @@ mktime (localtime (time ()))
 
   octave_scalar_map map = args(0).xscalar_map_value ("mktime: TM_STRUCT argument must be a structure");
 
-  octave::sys::base_tm tm = extract_tm (map, "mktime");
+  sys::base_tm tm = extract_tm (map, "mktime");
 
-  return ovl (octave::sys::time (tm));
+  return ovl (sys::time (tm));
 }
 
 /*
@@ -284,7 +293,7 @@ mktime (localtime (time ()))
 
 DEFUN (strftime, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} strftime (@var{fmt}, @var{tm_struct})
+@deftypefn {} {@var{str} =} strftime (@var{fmt}, @var{tm_struct})
 Format the time structure @var{tm_struct} in a flexible way using the format
 string @var{fmt} that contains @samp{%} substitutions similar to those in
 @code{printf}.
@@ -437,7 +446,8 @@ Last two digits of year (00-99).
 @item %Y
 Year (1970-).
 @end table
-@seealso{strptime, localtime, gmtime, mktime, time, now, date, clock, datenum, datestr, datevec, calendar, weekday}
+@seealso{strptime, localtime, gmtime, mktime, time, now, date, clock, datenum,
+datestr, datevec, calendar, weekday}
 @end deftypefn */)
 {
   if (args.length () != 2)
@@ -447,7 +457,7 @@ Year (1970-).
 
   octave_scalar_map map = args(1).xscalar_map_value ("strftime: TM_STRUCT must be a structure");
 
-  octave::sys::base_tm tm = extract_tm (map, "strftime");
+  sys::base_tm tm = extract_tm (map, "strftime");
 
   return ovl (tm.strftime (fmt));
 }
@@ -474,7 +484,8 @@ the control of the format string @var{fmt}.
 If @var{fmt} fails to match, @var{nchars} is 0; otherwise, it is set to the
 position of last matched character plus 1.  Always check for this unless
 you're absolutely sure the date string will be parsed correctly.
-@seealso{strftime, localtime, gmtime, mktime, time, now, date, clock, datenum, datestr, datevec, calendar, weekday}
+@seealso{strftime, localtime, gmtime, mktime, time, now, date, clock, datenum,
+datestr, datevec, calendar, weekday}
 @end deftypefn */)
 {
   if (args.length () != 2)
@@ -484,7 +495,7 @@ you're absolutely sure the date string will be parsed correctly.
 
   std::string fmt = args(1).xstring_value ("strptime: FMT must be a string");
 
-  octave::sys::strptime t (str, fmt);
+  sys::strptime t (str, fmt);
 
   return ovl (mk_tm_map (t), t.characters_converted ());
 }
@@ -508,3 +519,5 @@ you're absolutely sure the date string will be parsed correctly.
 
 %!error strptime ()
 */
+
+OCTAVE_END_NAMESPACE(octave)
