@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -79,20 +79,20 @@ default_numeric_conversion_function (const octave_base_value& a)
 }
 
 octave_base_value::type_conv_info
-octave_bool_matrix::numeric_conversion_function (void) const
+octave_bool_matrix::numeric_conversion_function () const
 {
   return octave_base_value::type_conv_info (default_numeric_conversion_function,
-                                            octave_matrix::static_type_id ());
+         octave_matrix::static_type_id ());
 }
 
 octave_base_value *
-octave_bool_matrix::try_narrowing_conversion (void)
+octave_bool_matrix::try_narrowing_conversion ()
 {
   octave_base_value *retval = nullptr;
 
-  if (matrix.ndims () == 2)
+  if (m_matrix.ndims () == 2)
     {
-      boolMatrix bm (matrix);
+      boolMatrix bm (m_matrix);
 
       octave_idx_type nr = bm.rows ();
       octave_idx_type nc = bm.cols ();
@@ -113,7 +113,7 @@ octave_bool_matrix::double_value (bool) const
   warn_implicit_conversion ("Octave:array-to-scalar",
                             "bool matrix", "real scalar");
 
-  return matrix(0, 0);
+  return m_matrix(0, 0);
 }
 
 float
@@ -125,7 +125,7 @@ octave_bool_matrix::float_value (bool) const
   warn_implicit_conversion ("Octave:array-to-scalar",
                             "bool matrix", "real scalar");
 
-  return matrix(0, 0);
+  return m_matrix(0, 0);
 }
 
 Complex
@@ -137,7 +137,7 @@ octave_bool_matrix::complex_value (bool) const
   warn_implicit_conversion ("Octave:array-to-scalar",
                             "bool matrix", "complex scalar");
 
-  return Complex (matrix(0, 0), 0);
+  return Complex (m_matrix(0, 0), 0);
 }
 
 FloatComplex
@@ -153,84 +153,84 @@ octave_bool_matrix::float_complex_value (bool) const
   warn_implicit_conversion ("Octave:array-to-scalar",
                             "bool matrix", "complex scalar");
 
-  retval = matrix(0, 0);
+  retval = m_matrix(0, 0);
 
   return retval;
 }
 
 octave_value
 octave_bool_matrix::convert_to_str_internal (bool pad, bool force,
-                                             char type) const
+    char type) const
 {
   octave_value tmp = octave_value (array_value ());
   return tmp.convert_to_str (pad, force, type);
 }
 
 octave_value
-octave_bool_matrix::as_double (void) const
+octave_bool_matrix::as_double () const
 {
-  return NDArray (matrix);
+  return NDArray (m_matrix);
 }
 
 octave_value
-octave_bool_matrix::as_single (void) const
+octave_bool_matrix::as_single () const
 {
-  return FloatNDArray (matrix);
+  return FloatNDArray (m_matrix);
 }
 
 octave_value
-octave_bool_matrix::as_int8 (void) const
+octave_bool_matrix::as_int8 () const
 {
-  return int8NDArray (matrix);
+  return int8NDArray (m_matrix);
 }
 
 octave_value
-octave_bool_matrix::as_int16 (void) const
+octave_bool_matrix::as_int16 () const
 {
-  return int16NDArray (matrix);
+  return int16NDArray (m_matrix);
 }
 
 octave_value
-octave_bool_matrix::as_int32 (void) const
+octave_bool_matrix::as_int32 () const
 {
-  return int32NDArray (matrix);
+  return int32NDArray (m_matrix);
 }
 
 octave_value
-octave_bool_matrix::as_int64 (void) const
+octave_bool_matrix::as_int64 () const
 {
-  return int64NDArray (matrix);
+  return int64NDArray (m_matrix);
 }
 
 octave_value
-octave_bool_matrix::as_uint8 (void) const
+octave_bool_matrix::as_uint8 () const
 {
-  return uint8NDArray (matrix);
+  return uint8NDArray (m_matrix);
 }
 
 octave_value
-octave_bool_matrix::as_uint16 (void) const
+octave_bool_matrix::as_uint16 () const
 {
-  return uint16NDArray (matrix);
+  return uint16NDArray (m_matrix);
 }
 
 octave_value
-octave_bool_matrix::as_uint32 (void) const
+octave_bool_matrix::as_uint32 () const
 {
-  return uint32NDArray (matrix);
+  return uint32NDArray (m_matrix);
 }
 
 octave_value
-octave_bool_matrix::as_uint64 (void) const
+octave_bool_matrix::as_uint64 () const
 {
-  return uint64NDArray (matrix);
+  return uint64NDArray (m_matrix);
 }
 
 void
 octave_bool_matrix::print_raw (std::ostream& os,
                                bool pr_as_read_syntax) const
 {
-  octave_print_internal (os, matrix, pr_as_read_syntax,
+  octave_print_internal (os, m_matrix, pr_as_read_syntax,
                          current_print_indent_level ());
 }
 
@@ -296,7 +296,7 @@ octave_bool_matrix::load_ascii (std::istream& is)
       boolNDArray btmp (dv);
 
       if (btmp.isempty ())
-        matrix = btmp;
+        m_matrix = btmp;
       else
         {
           NDArray tmp(dv);
@@ -308,7 +308,7 @@ octave_bool_matrix::load_ascii (std::istream& is)
           for (octave_idx_type i = 0; i < btmp.numel (); i++)
             btmp.elem (i) = (tmp.elem (i) != 0.);
 
-          matrix = btmp;
+          m_matrix = btmp;
         }
     }
   else if (kw == "rows")
@@ -329,12 +329,12 @@ octave_bool_matrix::load_ascii (std::istream& is)
           boolMatrix btmp (nr, nc);
           for (octave_idx_type j = 0; j < nc; j++)
             for (octave_idx_type i = 0; i < nr; i++)
-              btmp.elem (i,j) = (tmp.elem (i, j) != 0.);
+              btmp.elem (i, j) = (tmp.elem (i, j) != 0.);
 
-          matrix = btmp;
+          m_matrix = btmp;
         }
       else if (nr == 0 || nc == 0)
-        matrix = boolMatrix (nr, nc);
+        m_matrix = boolMatrix (nr, nc);
       else
         panic_impossible ();
     }
@@ -361,15 +361,9 @@ octave_bool_matrix::save_binary (std::ostream& os, bool /* save_as_floats */)
       os.write (reinterpret_cast<char *> (&tmp), 4);
     }
 
-  boolNDArray m = bool_array_value ();
-  bool *mtmp = m.fortran_vec ();
-  octave_idx_type nel = m.numel ();
-  OCTAVE_LOCAL_BUFFER (char, htmp, nel);
-
-  for (octave_idx_type i = 0; i < nel; i++)
-    htmp[i] = (mtmp[i] ? 1 : 0);
-
-  os.write (htmp, nel);
+  const bool *mtmp = m_matrix.data ();
+  octave_idx_type nel = m_matrix.numel ();
+  os.write (reinterpret_cast<const char *> (mtmp), nel);
 
   return true;
 }
@@ -423,7 +417,7 @@ octave_bool_matrix::load_binary (std::istream& is, bool swap,
   bool *mtmp = m.fortran_vec ();
   for (octave_idx_type i = 0; i < nel; i++)
     mtmp[i] = (htmp[i] ? 1 : 0);
-  matrix = m;
+  m_matrix = m;
 
   return true;
 }
@@ -444,7 +438,6 @@ octave_bool_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
   int rank = dv.ndims ();
   hid_t space_hid, data_hid;
   space_hid = data_hid = -1;
-  boolNDArray m = bool_array_value ();
 
   OCTAVE_LOCAL_BUFFER (hsize_t, hdims, rank);
 
@@ -456,7 +449,8 @@ octave_bool_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
   if (space_hid < 0) return false;
 #if defined (HAVE_HDF5_18)
   data_hid = H5Dcreate (loc_id, name, H5T_NATIVE_HBOOL, space_hid,
-                        octave_H5P_DEFAULT, octave_H5P_DEFAULT, octave_H5P_DEFAULT);
+                        octave_H5P_DEFAULT, octave_H5P_DEFAULT,
+                        octave_H5P_DEFAULT);
 #else
   data_hid = H5Dcreate (loc_id, name, H5T_NATIVE_HBOOL, space_hid,
                         octave_H5P_DEFAULT);
@@ -467,15 +461,11 @@ octave_bool_matrix::save_hdf5 (octave_hdf5_id loc_id, const char *name,
       return false;
     }
 
-  octave_idx_type nel = m.numel ();
-  bool *mtmp = m.fortran_vec ();
-  OCTAVE_LOCAL_BUFFER (hbool_t, htmp, nel);
-
-  for (octave_idx_type i = 0; i < nel; i++)
-    htmp[i] = mtmp[i];
+  const bool *mtmp = m_matrix.data ();
 
   retval = H5Dwrite (data_hid, H5T_NATIVE_HBOOL, octave_H5S_ALL, octave_H5S_ALL,
-                     octave_H5P_DEFAULT, htmp) >= 0;
+                     octave_H5P_DEFAULT,
+                     reinterpret_cast<const char *> (mtmp)) >= 0;
 
   H5Dclose (data_hid);
   H5Sclose (space_hid);
@@ -500,7 +490,7 @@ octave_bool_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
   dim_vector dv;
   int empty = load_hdf5_empty (loc_id, name, dv);
   if (empty > 0)
-    matrix.resize (dv);
+    m_matrix.resize (dv);
   if (empty)
     return (empty > 0);
 
@@ -550,7 +540,7 @@ octave_bool_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
       for (octave_idx_type i = 0; i < nel; i++)
         btmp.elem (i) = htmp[i];
 
-      matrix = btmp;
+      m_matrix = btmp;
     }
 
   H5Dclose (data_hid);
@@ -566,33 +556,35 @@ octave_bool_matrix::load_hdf5 (octave_hdf5_id loc_id, const char *name)
 }
 
 mxArray *
-octave_bool_matrix::as_mxArray (void) const
+octave_bool_matrix::as_mxArray (bool interleaved) const
 {
-  mxArray *retval = new mxArray (mxLOGICAL_CLASS, dims (), mxREAL);
+  mxArray *retval = new mxArray (interleaved, mxLOGICAL_CLASS, dims (), mxREAL);
 
-  bool *pr = static_cast<bool *> (retval->get_data ());
+  mxLogical *pd = static_cast<mxLogical *> (retval->get_data ());
 
   mwSize nel = numel ();
 
-  const bool *p = matrix.data ();
+  const bool *pdata = m_matrix.data ();
 
   for (mwIndex i = 0; i < nel; i++)
-    pr[i] = p[i];
+    pd[i] = pdata[i];
 
   return retval;
 }
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 DEFUN (logical, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} logical (@var{x})
+@deftypefn {} {@var{TF} =} logical (@var{x})
 Convert the numeric object @var{x} to logical type.
 
 Any nonzero values will be converted to true (1) while zero values will be
-converted to false (0).  The non-numeric value NaN cannot be converted and
-will produce an error.
+converted to false (0).  The non-numeric value NaN cannot be converted and will
+produce an error.
 
-Compatibility Note: Octave accepts complex values as input, whereas
-@sc{matlab} issues an error.
+Compatibility Note: Octave accepts complex values as input, whereas @sc{matlab}
+issues an error.
 @seealso{double, single, char}
 @end deftypefn */)
 {
@@ -630,3 +622,5 @@ Compatibility Note: Octave accepts complex values as input, whereas
 %!   assert (logical (eye (1, c{i})), s);
 %! endfor
 */
+
+OCTAVE_END_NAMESPACE(octave)
