@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2022 The Octave Project Developers
+// Copyright (C) 1996-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -38,12 +38,13 @@
 #include "ov-typeinfo.h"
 #include "symscope.h"
 
-namespace octave
-{
-  class stack_frame;
-  class tree_evaluator;
-  class tree_walker;
-}
+OCTAVE_BEGIN_NAMESPACE(octave)
+
+class stack_frame;
+class tree_evaluator;
+class tree_walker;
+
+OCTAVE_END_NAMESPACE(octave)
 
 // Functions.
 
@@ -53,60 +54,58 @@ octave_function : public octave_base_value
 {
 public:
 
-  octave_function (void)
+  octave_function ()
     : m_relative (false), m_locked (false), m_private (false),
       m_dispatch_class (), m_package_name (), m_name (), m_dir_name (),
       m_doc () { }
 
-  // No copying!
+  OCTAVE_DISABLE_COPY_MOVE (octave_function)
 
-  octave_function (const octave_function& f) = delete;
+  ~octave_function () = default;
 
-  octave_function& operator = (const octave_function& f) = delete;
+  octave_base_value * clone () const;
+  octave_base_value * empty_clone () const;
 
-  ~octave_function (void) = default;
+  bool is_defined () const { return true; }
 
-  octave_base_value * clone (void) const;
-  octave_base_value * empty_clone (void) const;
+  bool is_function () const { return true; }
 
-  bool is_defined (void) const { return true; }
+  virtual bool is_system_fcn_file () const { return false; }
 
-  bool is_function (void) const { return true; }
+  virtual std::string fcn_file_name () const { return ""; }
 
-  virtual bool is_system_fcn_file (void) const { return false; }
-
-  virtual std::string fcn_file_name (void) const { return ""; }
-
-  virtual std::string src_file_name (void) const { return ""; }
+  virtual std::string src_file_name () const { return ""; }
 
   // The name to show in the profiler (also used as map-key).
-  virtual std::string profiler_name (void) const { return name (); }
+  virtual std::string profiler_name () const { return name (); }
 
-  virtual std::string parent_fcn_name (void) const { return ""; }
+  virtual std::string parent_fcn_name () const { return ""; }
 
-  virtual octave::symbol_scope parent_fcn_scope (void) const
-  { return octave::symbol_scope (); }
+  virtual octave::symbol_scope parent_fcn_scope () const
+  { return octave::symbol_scope::invalid (); }
 
-  virtual std::list<std::string> parent_fcn_names (void) const
+  virtual std::list<std::string> parent_fcn_names () const
   { return std::list<std::string> (); }
 
   virtual void mark_fcn_file_up_to_date (const octave::sys::time&) { }
 
-  virtual octave::symbol_scope scope (void) { return octave::symbol_scope (); }
+  virtual octave::symbol_scope scope () { return octave::symbol_scope::invalid (); }
 
-  virtual octave::sys::time time_parsed (void) const
-  { return octave::sys::time (static_cast<time_t> (0)); }
+  virtual octave::sys::time time_parsed () const
+  { return octave::sys::time (static_cast<OCTAVE_TIME_T> (0)); }
 
-  virtual octave::sys::time time_checked (void) const
-  { return octave::sys::time (static_cast<time_t> (0)); }
+  virtual octave::sys::time time_checked () const
+  { return octave::sys::time (static_cast<OCTAVE_TIME_T> (0)); }
 
-  virtual int call_depth (void) const { return 0; }
+  virtual int call_depth () const { return 0; }
 
-  virtual bool is_nested_function (void) const { return false; }
+  virtual bool is_nested_function () const { return false; }
 
-  virtual bool is_parent_function (void) const { return false; }
+  virtual bool is_parent_function () const { return false; }
 
-  virtual bool is_subfunction (void) const { return false; }
+  virtual bool is_subfunction () const { return false; }
+
+  virtual bool is_compiled () const { return false; }
 
   bool is_class_constructor (const std::string& cname = "") const
   {
@@ -132,9 +131,9 @@ public:
   virtual bool is_classdef_method (const std::string& = "") const
   { return false; }
 
-  virtual bool takes_varargs (void) const { return false; }
+  virtual bool takes_varargs () const { return false; }
 
-  virtual bool takes_var_return (void) const { return false; }
+  virtual bool takes_var_return () const { return false; }
 
   // The next two functions are for dispatching to built-in
   // functions given built-in classes.
@@ -146,11 +145,11 @@ public:
 
   void stash_dispatch_class (const std::string& nm) { m_dispatch_class = nm; }
 
-  std::string dispatch_class (void) const { return m_dispatch_class; }
+  std::string dispatch_class () const { return m_dispatch_class; }
 
   void stash_package_name (const std::string& pack) { m_package_name = pack; }
 
-  std::string package_name (void) const { return m_package_name; }
+  std::string package_name () const { return m_package_name; }
 
   virtual void
   mark_as_private_function (const std::string& cname = "")
@@ -159,7 +158,7 @@ public:
     m_dispatch_class = cname;
   }
 
-  bool is_private_function (void) const { return m_private; }
+  bool is_private_function () const { return m_private; }
 
   bool is_private_function_of_class (const std::string& nm) const
   { return m_private && m_dispatch_class == nm; }
@@ -168,45 +167,45 @@ public:
   is_anonymous_function_of_class (const std::string& = "") const
   { return false; }
 
-  std::string dir_name (void) const { return m_dir_name; }
+  std::string dir_name () const { return m_dir_name; }
 
   void stash_dir_name (const std::string& dir) { m_dir_name = dir; }
 
-  void lock (void)
+  void lock ()
   {
     this->lock_subfunctions ();
     m_locked = true;
   }
 
-  void unlock (void)
+  void unlock ()
   {
     this->unlock_subfunctions ();
     m_locked = false;
   }
 
-  bool islocked (void) const { return m_locked; }
+  bool islocked () const { return m_locked; }
 
-  virtual void lock_subfunctions (void) { }
+  virtual void lock_subfunctions () { }
 
-  virtual void unlock_subfunctions (void) { }
+  virtual void unlock_subfunctions () { }
 
-  virtual void maybe_relocate_end (void) { }
+  virtual void maybe_relocate_end () { }
 
   // Not valid until after the function is completely parsed.
-  virtual bool has_subfunctions (void) const { return false; }
+  virtual bool has_subfunctions () const { return false; }
 
   virtual void stash_subfunction_names (const std::list<std::string>&) { }
 
-  virtual std::list<std::string> subfunction_names (void) const
+  virtual std::list<std::string> subfunction_names () const
   { return std::list<std::string> (); }
 
-  void mark_relative (void) { m_relative = true; }
+  void mark_relative () { m_relative = true; }
 
-  bool is_relative (void) const { return m_relative; }
+  bool is_relative () const { return m_relative; }
 
-  std::string name (void) const { return m_name; }
+  std::string name () const { return m_name; }
 
-  std::string canonical_name (void) const
+  std::string canonical_name () const
   {
     if (m_package_name.empty ())
       return m_name;
@@ -219,7 +218,7 @@ public:
   virtual std::string
   doc_string (const std::string& /*meth_name*/ = "") const { return m_doc; }
 
-  virtual void unload (void) { }
+  virtual void unload () { }
 
   virtual void accept (octave::tree_walker&) { }
 
