@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2001-2023 The Octave Project Developers
+// Copyright (C) 2001-2024 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -65,7 +65,7 @@ fftw_planner *fftw_planner::s_instance = nullptr;
 
 // Note that it is profitable to store the FFTW3 plans, for small FFTs.
 
-fftw_planner::fftw_planner (void)
+fftw_planner::fftw_planner ()
   : m_meth (ESTIMATE), m_rplan (nullptr), m_rd (0), m_rs (0), m_rr (0),
     m_rh (0), m_rn (), m_rsimd_align (false), m_nthreads (1)
 {
@@ -97,7 +97,7 @@ fftw_planner::fftw_planner (void)
   fftw_import_system_wisdom ();
 }
 
-fftw_planner::~fftw_planner (void)
+fftw_planner::~fftw_planner ()
 {
   fftw_plan *plan_p;
 
@@ -115,7 +115,7 @@ fftw_planner::~fftw_planner (void)
 }
 
 bool
-fftw_planner::instance_ok (void)
+fftw_planner::instance_ok ()
 {
   bool retval = true;
 
@@ -244,31 +244,29 @@ fftw_planner::do_create_plan (int dir, const int rank,
       if (*cur_plan_p)
         fftw_destroy_plan (*cur_plan_p);
 
+      OCTAVE_SCOPED_BUFFER_ANCHOR (Complex, itmp);
+      itmp = const_cast<Complex *> (in);
+      Complex *otmp = out;
+
       if (plan_destroys_in)
         {
           // Create matrix with the same size and 16-byte alignment as input
-          OCTAVE_LOCAL_BUFFER (Complex, itmp, nn * howmany + 32);
+          OCTAVE_SCOPED_BUFFER (Complex, itmp, nn * howmany + 32);
           itmp = reinterpret_cast<Complex *>
-                 (((reinterpret_cast<std::ptrdiff_t> (itmp) + 15) & ~ 0xF) +
-                  ((reinterpret_cast<std::ptrdiff_t> (in)) & 0xF));
+                 (((reinterpret_cast<std::ptrdiff_t> (itmp) + 15) & ~ 0xF)
+                  + ((reinterpret_cast<std::ptrdiff_t> (in)) & 0xF));
 
-          *cur_plan_p
-            = fftw_plan_many_dft (rank, tmp, howmany,
-                                  reinterpret_cast<fftw_complex *> (itmp),
-                                  nullptr, stride, dist,
-                                  reinterpret_cast<fftw_complex *> (out),
-                                  nullptr, stride, dist, dir, plan_flags);
-        }
-      else
-        {
-          *cur_plan_p
-            = fftw_plan_many_dft (rank, tmp, howmany,
-                                  reinterpret_cast<fftw_complex *> (const_cast<Complex *> (in)),
-                                  nullptr, stride, dist,
-                                  reinterpret_cast<fftw_complex *> (out),
-                                  nullptr, stride, dist, dir, plan_flags);
+          if (in == out)
+            otmp = itmp;
         }
 
+      *cur_plan_p
+        = fftw_plan_many_dft (rank, tmp, howmany,
+                              reinterpret_cast<fftw_complex *> (itmp),
+                              nullptr, stride, dist,
+                              reinterpret_cast<fftw_complex *> (otmp),
+                              nullptr, stride, dist, dir, plan_flags);
+
       if (*cur_plan_p == nullptr)
         (*current_liboctave_error_handler) ("Error creating FFTW plan");
     }
@@ -363,30 +361,30 @@ fftw_planner::do_create_plan (const int rank, const dim_vector& dims,
       if (*cur_plan_p)
         fftw_destroy_plan (*cur_plan_p);
 
+      OCTAVE_SCOPED_BUFFER_ANCHOR (double, itmp);
+      itmp = const_cast<double *> (in);
+      Complex *otmp = out;
+
       if (plan_destroys_in)
         {
           // Create matrix with the same size and 16-byte alignment as input
-          OCTAVE_LOCAL_BUFFER (double, itmp, nn + 32);
+          octave_idx_type in_place = reinterpret_cast<double *> (out) == in;
+          OCTAVE_SCOPED_BUFFER (double, itmp,
+                                nn * howmany * (in_place + 1) + 32);
           itmp = reinterpret_cast<double *>
-                 (((reinterpret_cast<std::ptrdiff_t> (itmp) + 15) & ~ 0xF) +
-                  ((reinterpret_cast<std::ptrdiff_t> (in)) & 0xF));
+                 (((reinterpret_cast<std::ptrdiff_t> (itmp) + 15) & ~ 0xF)
+                  + ((reinterpret_cast<std::ptrdiff_t> (in)) & 0xF));
 
-          *cur_plan_p
-            = fftw_plan_many_dft_r2c (rank, tmp, howmany, itmp,
-                                      nullptr, stride, dist,
-                                      reinterpret_cast<fftw_complex *> (out),
-                                      nullptr, stride, dist, plan_flags);
-        }
-      else
-        {
-          *cur_plan_p
-            = fftw_plan_many_dft_r2c (rank, tmp, howmany,
-                                      (const_cast<double *> (in)),
-                                      nullptr, stride, dist,
-                                      reinterpret_cast<fftw_complex *> (out),
-                                      nullptr, stride, dist, plan_flags);
+          if (in_place)
+            otmp = reinterpret_cast<Complex *> (itmp);
         }
 
+      *cur_plan_p
+        = fftw_plan_many_dft_r2c (rank, tmp, howmany, itmp,
+                                  nullptr, stride, dist,
+                                  reinterpret_cast<fftw_complex *> (otmp),
+                                  nullptr, stride, dist, plan_flags);
+
       if (*cur_plan_p == nullptr)
         (*current_liboctave_error_handler) ("Error creating FFTW plan");
     }
@@ -395,7 +393,7 @@ fftw_planner::do_create_plan (const int rank, const dim_vector& dims,
 }
 
 fftw_planner::FftwMethod
-fftw_planner::do_method (void)
+fftw_planner::do_method ()
 {
   return m_meth;
 }
@@ -427,7 +425,7 @@ fftw_planner::do_method (FftwMethod _meth)
 
 float_fftw_planner *float_fftw_planner::s_instance = nullptr;
 
-float_fftw_planner::float_fftw_planner (void)
+float_fftw_planner::float_fftw_planner ()
   : m_meth (ESTIMATE), m_rplan (nullptr), m_rd (0), m_rs (0), m_rr (0),
     m_rh (0), m_rn (), m_rsimd_align (false), m_nthreads (1)
 {
@@ -454,7 +452,7 @@ float_fftw_planner::float_fftw_planner (void)
   fftwf_import_system_wisdom ();
 }
 
-float_fftw_planner::~float_fftw_planner (void)
+float_fftw_planner::~float_fftw_planner ()
 {
   fftwf_plan *plan_p;
 
@@ -472,7 +470,7 @@ float_fftw_planner::~float_fftw_planner (void)
 }
 
 bool
-float_fftw_planner::instance_ok (void)
+float_fftw_planner::instance_ok ()
 {
   bool retval = true;
 
@@ -599,31 +597,29 @@ float_fftw_planner::do_create_plan (int dir, const int rank,
       if (*cur_plan_p)
         fftwf_destroy_plan (*cur_plan_p);
 
+      OCTAVE_SCOPED_BUFFER_ANCHOR (FloatComplex, itmp);
+      itmp = const_cast<FloatComplex *> (in);
+      FloatComplex *otmp = out;
+
       if (plan_destroys_in)
         {
           // Create matrix with the same size and 16-byte alignment as input
-          OCTAVE_LOCAL_BUFFER (FloatComplex, itmp, nn * howmany + 32);
+          OCTAVE_SCOPED_BUFFER (FloatComplex, itmp, nn * howmany + 32);
           itmp = reinterpret_cast<FloatComplex *>
-                 (((reinterpret_cast<std::ptrdiff_t> (itmp) + 15) & ~ 0xF) +
-                  ((reinterpret_cast<std::ptrdiff_t> (in)) & 0xF));
+                 (((reinterpret_cast<std::ptrdiff_t> (itmp) + 15) & ~ 0xF)
+                  + ((reinterpret_cast<std::ptrdiff_t> (in)) & 0xF));
 
-          *cur_plan_p
-            = fftwf_plan_many_dft (rank, tmp, howmany,
-                                   reinterpret_cast<fftwf_complex *> (itmp),
-                                   nullptr, stride, dist,
-                                   reinterpret_cast<fftwf_complex *> (out),
-                                   nullptr, stride, dist, dir, plan_flags);
-        }
-      else
-        {
-          *cur_plan_p
-            = fftwf_plan_many_dft (rank, tmp, howmany,
-                                   reinterpret_cast<fftwf_complex *> (const_cast<FloatComplex *> (in)),
-                                   nullptr, stride, dist,
-                                   reinterpret_cast<fftwf_complex *> (out),
-                                   nullptr, stride, dist, dir, plan_flags);
+          if (out == in)
+            otmp = itmp;
         }
 
+      *cur_plan_p
+        = fftwf_plan_many_dft (rank, tmp, howmany,
+                               reinterpret_cast<fftwf_complex *> (itmp),
+                               nullptr, stride, dist,
+                               reinterpret_cast<fftwf_complex *> (otmp),
+                               nullptr, stride, dist, dir, plan_flags);
+
       if (*cur_plan_p == nullptr)
         (*current_liboctave_error_handler) ("Error creating FFTW plan");
     }
@@ -718,30 +714,30 @@ float_fftw_planner::do_create_plan (const int rank, const dim_vector& dims,
       if (*cur_plan_p)
         fftwf_destroy_plan (*cur_plan_p);
 
+      OCTAVE_SCOPED_BUFFER_ANCHOR (float, itmp);
+      itmp = const_cast<float *> (in);
+      FloatComplex *otmp = out;
+
       if (plan_destroys_in)
         {
           // Create matrix with the same size and 16-byte alignment as input
-          OCTAVE_LOCAL_BUFFER (float, itmp, nn + 32);
+          octave_idx_type in_place = reinterpret_cast<float *> (out) == in;
+          OCTAVE_SCOPED_BUFFER (float, itmp,
+                                nn * howmany * (in_place + 1) + 32);
           itmp = reinterpret_cast<float *>
-                 (((reinterpret_cast<std::ptrdiff_t> (itmp) + 15) & ~ 0xF) +
-                  ((reinterpret_cast<std::ptrdiff_t> (in)) & 0xF));
+                 (((reinterpret_cast<std::ptrdiff_t> (itmp) + 15) & ~ 0xF)
+                  + ((reinterpret_cast<std::ptrdiff_t> (in)) & 0xF));
 
-          *cur_plan_p
-            = fftwf_plan_many_dft_r2c (rank, tmp, howmany, itmp,
-                                       nullptr, stride, dist,
-                                       reinterpret_cast<fftwf_complex *> (out),
-                                       nullptr, stride, dist, plan_flags);
-        }
-      else
-        {
-          *cur_plan_p
-            = fftwf_plan_many_dft_r2c (rank, tmp, howmany,
-                                       (const_cast<float *> (in)),
-                                       nullptr, stride, dist,
-                                       reinterpret_cast<fftwf_complex *> (out),
-                                       nullptr, stride, dist, plan_flags);
+          if (in_place)
+            otmp = reinterpret_cast<FloatComplex *> (itmp);
         }
 
+      *cur_plan_p
+        = fftwf_plan_many_dft_r2c (rank, tmp, howmany, itmp,
+                                   nullptr, stride, dist,
+                                   reinterpret_cast<fftwf_complex *> (otmp),
+                                   nullptr, stride, dist, plan_flags);
+
       if (*cur_plan_p == nullptr)
         (*current_liboctave_error_handler) ("Error creating FFTW plan");
     }
@@ -750,7 +746,7 @@ float_fftw_planner::do_create_plan (const int rank, const dim_vector& dims,
 }
 
 float_fftw_planner::FftwMethod
-float_fftw_planner::do_method (void)
+float_fftw_planner::do_method ()
 {
   return m_meth;
 }
@@ -871,7 +867,7 @@ fftw::fft (const double *in, Complex *out, std::size_t npts,
                 stride, dist, in, out);
   fftw_plan m_plan = reinterpret_cast<fftw_plan> (vplan);
 
-  fftw_execute_dft_r2c (m_plan, (const_cast<double *>(in)),
+  fftw_execute_dft_r2c (m_plan, (const_cast<double *> (in)),
                         reinterpret_cast<fftw_complex *> (out));
 
   // Need to create other half of the transform.
@@ -895,7 +891,7 @@ fftw::fft (const Complex *in, Complex *out, std::size_t npts,
   fftw_plan m_plan = reinterpret_cast<fftw_plan> (vplan);
 
   fftw_execute_dft (m_plan,
-                    reinterpret_cast<fftw_complex *> (const_cast<Complex *>(in)),
+                    reinterpret_cast<fftw_complex *> (const_cast<Complex *> (in)),
                     reinterpret_cast<fftw_complex *> (out));
 
   return 0;
@@ -914,7 +910,7 @@ fftw::ifft (const Complex *in, Complex *out, std::size_t npts,
   fftw_plan m_plan = reinterpret_cast<fftw_plan> (vplan);
 
   fftw_execute_dft (m_plan,
-                    reinterpret_cast<fftw_complex *> (const_cast<Complex *>(in)),
+                    reinterpret_cast<fftw_complex *> (const_cast<Complex *> (in)),
                     reinterpret_cast<fftw_complex *> (out));
 
   const Complex scale = npts;
@@ -942,7 +938,7 @@ fftw::fftNd (const double *in, Complex *out, const int rank,
                 in, out + offset);
   fftw_plan m_plan = reinterpret_cast<fftw_plan> (vplan);
 
-  fftw_execute_dft_r2c (m_plan, (const_cast<double *>(in)),
+  fftw_execute_dft_r2c (m_plan, (const_cast<double *> (in)),
                         reinterpret_cast<fftw_complex *> (out+ offset));
 
   // Need to create other half of the transform.
@@ -965,7 +961,7 @@ fftw::fftNd (const Complex *in, Complex *out, const int rank,
   fftw_plan m_plan = reinterpret_cast<fftw_plan> (vplan);
 
   fftw_execute_dft (m_plan,
-                    reinterpret_cast<fftw_complex *> (const_cast<Complex *>(in)),
+                    reinterpret_cast<fftw_complex *> (const_cast<Complex *> (in)),
                     reinterpret_cast<fftw_complex *> (out));
 
   return 0;
@@ -984,7 +980,7 @@ fftw::ifftNd (const Complex *in, Complex *out, const int rank,
   fftw_plan m_plan = reinterpret_cast<fftw_plan> (vplan);
 
   fftw_execute_dft (m_plan,
-                    reinterpret_cast<fftw_complex *> (const_cast<Complex *>(in)),
+                    reinterpret_cast<fftw_complex *> (const_cast<Complex *> (in)),
                     reinterpret_cast<fftw_complex *> (out));
 
   const std::size_t npts = dv.numel ();
@@ -1007,7 +1003,7 @@ fftw::fft (const float *in, FloatComplex *out, std::size_t npts,
                 dist, in, out);
   fftwf_plan m_plan = reinterpret_cast<fftwf_plan> (vplan);
 
-  fftwf_execute_dft_r2c (m_plan, (const_cast<float *>(in)),
+  fftwf_execute_dft_r2c (m_plan, (const_cast<float *> (in)),
                          reinterpret_cast<fftwf_complex *> (out));
 
   // Need to create other half of the transform.
@@ -1031,7 +1027,7 @@ fftw::fft (const FloatComplex *in, FloatComplex *out, std::size_t npts,
   fftwf_plan m_plan = reinterpret_cast<fftwf_plan> (vplan);
 
   fftwf_execute_dft (m_plan,
-                     reinterpret_cast<fftwf_complex *> (const_cast<FloatComplex *>(in)),
+                     reinterpret_cast<fftwf_complex *> (const_cast<FloatComplex *> (in)),
                      reinterpret_cast<fftwf_complex *> (out));
 
   return 0;
@@ -1051,7 +1047,7 @@ fftw::ifft (const FloatComplex *in, FloatComplex *out, std::size_t npts,
   fftwf_plan m_plan = reinterpret_cast<fftwf_plan> (vplan);
 
   fftwf_execute_dft (m_plan,
-                     reinterpret_cast<fftwf_complex *> (const_cast<FloatComplex *>(in)),
+                     reinterpret_cast<fftwf_complex *> (const_cast<FloatComplex *> (in)),
                      reinterpret_cast<fftwf_complex *> (out));
 
   const FloatComplex scale = npts;
@@ -1079,7 +1075,7 @@ fftw::fftNd (const float *in, FloatComplex *out, const int rank,
                 in, out + offset);
   fftwf_plan m_plan = reinterpret_cast<fftwf_plan> (vplan);
 
-  fftwf_execute_dft_r2c (m_plan, (const_cast<float *>(in)),
+  fftwf_execute_dft_r2c (m_plan, (const_cast<float *> (in)),
                          reinterpret_cast<fftwf_complex *> (out+ offset));
 
   // Need to create other half of the transform.
@@ -1102,7 +1098,7 @@ fftw::fftNd (const FloatComplex *in, FloatComplex *out, const int rank,
   fftwf_plan m_plan = reinterpret_cast<fftwf_plan> (vplan);
 
   fftwf_execute_dft (m_plan,
-                     reinterpret_cast<fftwf_complex *> (const_cast<FloatComplex *>(in)),
+                     reinterpret_cast<fftwf_complex *> (const_cast<FloatComplex *> (in)),
                      reinterpret_cast<fftwf_complex *> (out));
 
   return 0;
@@ -1121,7 +1117,7 @@ fftw::ifftNd (const FloatComplex *in, FloatComplex *out, const int rank,
   fftwf_plan m_plan = reinterpret_cast<fftwf_plan> (vplan);
 
   fftwf_execute_dft (m_plan,
-                     reinterpret_cast<fftwf_complex *> (const_cast<FloatComplex *>(in)),
+                     reinterpret_cast<fftwf_complex *> (const_cast<FloatComplex *> (in)),
                      reinterpret_cast<fftwf_complex *> (out));
 
   const std::size_t npts = dv.numel ();
@@ -1135,7 +1131,7 @@ fftw::ifftNd (const FloatComplex *in, FloatComplex *out, const int rank,
 #endif
 
 std::string
-fftw_version (void)
+fftw_version ()
 {
 #if defined (HAVE_FFTW)
   return ::fftw_version;
@@ -1145,7 +1141,7 @@ fftw_version (void)
 }
 
 std::string
-fftwf_version (void)
+fftwf_version ()
 {
 #if defined (HAVE_FFTW)
   return ::fftwf_version;
