@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2014-2021 The Octave Project Developers
+## Copyright (C) 2014-2024 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,8 +24,8 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} isbanded (@var{A}, @var{lower}, @var{upper})
-## Return true if @var{A} is a matrix with entries confined between
+## @deftypefn {} {@var{tf} =} isbanded (@var{A}, @var{lower}, @var{upper})
+## Return true if @var{A} is a numeric matrix with entries confined between
 ## @var{lower} diagonals below the main diagonal and @var{upper} diagonals
 ## above the main diagonal.
 ##
@@ -33,7 +33,7 @@
 ## @seealso{isdiag, istril, istriu, bandwidth}
 ## @end deftypefn
 
-function retval = isbanded (A, lower, upper)
+function tf = isbanded (A, lower, upper)
 
   if (nargin != 3)
     print_usage ();
@@ -44,16 +44,16 @@ function retval = isbanded (A, lower, upper)
   endif
 
   if (isempty (A))
-    retval = [];
+    tf = [];
   else
-    retval = (isnumeric (A) || islogical (A)) && ndims (A) == 2;
-    if (retval)
+    tf = (isnumeric (A) || islogical (A)) && ndims (A) == 2;
+    if (tf)
       [i, j] = find (A);
       pupp = j >= i;
-      retval = all (j(pupp) - i(pupp) <= upper);
-      if (retval)
+      tf = all (j(pupp) - i(pupp) <= upper);
+      if (tf)
         plow = i >= j;
-        retval = all (i(plow) - j(plow) <= lower);
+        tf = all (i(plow) - j(plow) <= lower);
       endif
     endif
   endif
@@ -69,9 +69,9 @@ endfunction
 
 %!assert (isbanded ([1, 1],1,1))
 %!assert (isbanded ([1; 1],1,1))
-%!assert (isbanded (eye(10),0,0))
-%!assert (isbanded (eye(10),1,1))
-%!assert (isbanded (i*eye(10),1,1))
+%!assert (isbanded (eye (10),0,0))
+%!assert (isbanded (eye (10),1,1))
+%!assert (isbanded (i*eye (10),1,1))
 %!assert (isbanded (logical (eye (10)),1,1))
 
 %! A = [2 3 0 0 0; 1 2 3 0 0; 0 1 2 3 0; 0 0 1 2 3; 0 0 0 1 2];
@@ -80,10 +80,9 @@ endfunction
 %! assert (! isbanded (A,1,0));
 
 ## Test input validation
-%!error isbanded ()
-%!error isbanded (1)
-%!error isbanded (1,2)
-%!error isbanded (1,2,3,4)
+%!error <Invalid call> isbanded ()
+%!error <Invalid call> isbanded (1)
+%!error <Invalid call> isbanded (1,2)
 %!error <LOWER and UPPER must be non-negative> isbanded (1, -1, 1)
 %!error <LOWER and UPPER must be non-negative> isbanded (1, 1, -1)
 %!error <LOWER and UPPER must be non-negative> isbanded (1, {1}, 1)
