@@ -1,28 +1,35 @@
-## Copyright (C) 1993-2013 John W. Eaton
+########################################################################
+##
+## Copyright (C) 1993-2024 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} mesh (@var{x}, @var{y}, @var{z})
-## @deftypefnx {Function File} {} mesh (@var{z})
-## @deftypefnx {Function File} {} mesh (@dots{}, @var{c})
-## @deftypefnx {Function File} {} mesh (@dots{}, @var{prop}, @var{val}, @dots{})
-## @deftypefnx {Function File} {} mesh (@var{hax}, @dots{})
-## @deftypefnx {Function File} {@var{h} =} mesh (@dots{})
+## @deftypefn  {} {} mesh (@var{x}, @var{y}, @var{z})
+## @deftypefnx {} {} mesh (@var{z})
+## @deftypefnx {} {} mesh (@dots{}, @var{c})
+## @deftypefnx {} {} mesh (@dots{}, @var{prop}, @var{val}, @dots{})
+## @deftypefnx {} {} mesh (@var{hax}, @dots{})
+## @deftypefnx {} {@var{h} =} mesh (@dots{})
 ## Plot a 3-D wireframe mesh.
 ##
 ## The wireframe mesh is plotted using rectangles.  The vertices of the
@@ -42,19 +49,19 @@
 ## by supplying a color matrix, @var{c}.
 ##
 ## Any property/value pairs are passed directly to the underlying surface
-## object.
+## object.  The full list of properties is documented at
+## @ref{Surface Properties}.
 ##
-## If the first argument @var{hax} is an axes handle, then plot into this axis,
+## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
 ##
 ## The optional return value @var{h} is a graphics handle to the created
 ## surface object.
 ##
-## @seealso{ezmesh, meshc, meshz, trimesh, contour, surf, surface, meshgrid, hidden, shading, colormap, caxis}
+## @seealso{ezmesh, meshc, meshz, trimesh, contour, surf, surface, meshgrid,
+## hidden, shading, colormap, caxis}
 ## @end deftypefn
 
-## Author: jwe
-
 function h = mesh (varargin)
 
   if (! all (cellfun ("isreal", varargin)))
@@ -70,10 +77,16 @@ function h = mesh (varargin)
   unwind_protect
     hax = newplot (hax);
 
-    htmp = surface (varargin{:});
+    mesh_props = {"facecolor", "w", "edgecolor", "flat", ...
+                  "facelighting", "none", "edgelighting", "flat"};
+    chararg = find (cellfun ("isclass", varargin, "char"), 1);
+    if (isempty (chararg))
+      htmp = surface (varargin{:}, mesh_props{:});
+    else
+      htmp = surface (varargin{1:chararg-1}, mesh_props{:},
+                      varargin{chararg:end});
+    endif
 
-    set (htmp, "facecolor", "w");
-    set (htmp, "edgecolor", "flat");
     if (! ishold ())
       set (hax, "view", [-37.5, 30],
                 "xgrid", "on", "ygrid", "on", "zgrid", "on");
@@ -96,32 +109,45 @@ endfunction
 %! x = logspace (0,1,11);
 %! z = x'*x;
 %! mesh (x, x, z);
-%! xlabel 'X-axis';
-%! ylabel 'Y-axis';
-%! zlabel 'Z-axis';
-%! title ('mesh() with color proportional to height');
+%! xlabel "X-axis";
+%! ylabel "Y-axis";
+%! zlabel "Z-axis";
+%! title ("mesh() with color proportional to height");
 
 %!demo
 %! clf;
 %! x = logspace (0,1,11);
 %! z = x'*x;
 %! mesh (x, x, z, z.^2);
-%! xlabel 'X-axis';
-%! ylabel 'Y-axis';
-%! zlabel 'linear scale';
-%! title ('mesh() with color proportional to Z^2');
+%! xlabel "X-axis";
+%! ylabel "Y-axis";
+%! zlabel "linear scale";
+%! title ("mesh() with color proportional to Z^2");
 
 %!demo
 %! clf;
 %! x = logspace (0,1,11);
 %! z = x'*x;
 %! mesh (x, x, z, z.^2);
-%! set (gca, 'zscale', 'log');
-%! xlabel 'X-axis';
-%! ylabel 'Y-axis';
-%! zlabel 'log scale';
-%! title ({'mesh() with color proportional to Z^2', 'Z-axis is log scale'});
-%! if (strcmp (get (gcf, '__graphics_toolkit__'), 'gnuplot'))
-%!   title ({'Gnuplot: mesh color is wrong', 'This is a Gnuplot bug'});
-%! endif
+%! set (gca, "zscale", "log");
+%! xlabel "X-axis";
+%! ylabel "Y-axis";
+%! zlabel "log scale";
+%! title ({"mesh() with color proportional to Z^2", "Z-axis is log scale"});
+%! try
+%!   if (strcmp (get (gcf, "__graphics_toolkit__"), "gnuplot"))
+%!     title ({"Gnuplot: mesh color is wrong", "This is a Gnuplot bug"});
+%!   endif
+%! catch
+%! end_try_catch
 
+%!demo
+%! clf;
+%! x = logspace (0,1,11);
+%! z = x'*x;
+%! mesh (x, x, z, "facecolor", "none", "edgecolor", "c");
+%! xlabel "X-axis";
+%! ylabel "Y-axis";
+%! zlabel "Z-axis";
+%! title ({"mesh() default properties overridden", ...
+%!         "transparent mesh with cyan color"});
