@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2008-2023 The Octave Project Developers
+## Copyright (C) 2008-2024 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -157,6 +157,20 @@
 ## Caution: If Octave was built against Qt version earlier than 5.13,
 ## @option{-svgconvert} may lead to inaccurate rendering of image objects.
 ##
+## @item  -polymerge
+## @itemx -nopolymerge
+## @itemx -polymerge-all
+##   When using the SVG based backend @option{-svgconvert}, faces are rendered
+## as triangles.  In some cases, some viewers might display fine lines where
+## those triangles share an edge.  These options control whether all triangles
+## that share edges are merged into polygons (@option{-polymerge-all} which
+## might take some time for graphics consisting of many triangles -- including
+## line markers), only consecutive polygons are merged (@option{-polymerge}),
+## or no triangles are merged at all (@option{-no-polymerge}).  By default,
+## only consecutive triangles sharing an edge are merged, unless the printed
+## figure contains patch or surface graphics objects in which case all
+## triangles that are sharing an edge are merged.
+##
 ## @item  -portrait
 ## @itemx -landscape
 ##   Specify the orientation of the plot for printed output.
@@ -411,6 +425,10 @@
 ## anti-aliasing is applied using Ghostscript's TextAlphaBits and
 ## GraphicsAlphaBits options.  The default number of bits are 4 and 1
 ## respectively.  Allowed values for @var{N} are 1, 2, or 4.
+##
+## @item -no-append-file-extension
+##   With this option, @var{filename} is used verbatim.  That means no file
+## extension matching the file format is appended automatically.
 ## @end table
 ##
 ## @seealso{saveas, getframe, savefig, hgsave, orient, figure}
@@ -809,6 +827,26 @@ function RGB = print (varargin)
 
 endfunction
 
+## Print to file with and without file extension
+%!testif ; (have_window_system () && any (strcmp ("qt", available_graphics_toolkits ())))
+%! toolkit = graphics_toolkit ();
+%! graphics_toolkit ("qt");
+%! hf = figure ("visible", "off");
+%! unwind_protect
+%!   x = 0:0.1:1;
+%!   hax = axes (hf);
+%!   plot (hax, x, x);
+%!   tmp_name = tempname ();
+%!   print (hf, tmp_name, "-dpng");
+%!   assert (isfile ([tmp_name ".png"]));
+%!   unlink ([tmp_name ".png"]);
+%!   print (hf, tmp_name, "-dpng", "-no-append-file-extension");
+%!   assert (isfile (tmp_name));
+%!   unlink (tmp_name);
+%! unwind_protect_cleanup
+%!   close (hf);
+%!   graphics_toolkit (toolkit);
+%! end_unwind_protect
 
 %!error <a graphics handle>
 %! hf = figure ("visible", "off");
@@ -1160,7 +1198,8 @@ function cmd = svgconvert (opts, devopt)
     cmd = sprintf ('%s - %%s %3.2f "%s" %d "%%s"', ...
                    undo_string_escapes (opts.svgconvert_binary), ...
                    get (0, "screenpixelsperinch"), ...
-                   undo_string_escapes (fullfile (fontdir, "FreeSans.otf")), 1);
+                   undo_string_escapes (fullfile (fontdir, "FreeSans.otf")),
+                   opts.polymerge);
 
     if (opts.debug)
       fprintf ("svgconvert command: '%s'\n", cmd);
