@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1995-2022 The Octave Project Developers
+## Copyright (C) 1995-2024 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -132,7 +132,7 @@
 ## @seealso{axes, plot, gca, set}
 ## @end deftypefn
 
-function h = subplot (varargin)
+function hax = subplot (varargin)
 
   align_axes = false;
   replace_axes = false;
@@ -288,7 +288,7 @@ function h = subplot (varargin)
               ## appdata "__subplotposition__", use the existing axes.
               found = true;
               hsubplot = child;
-            else
+            elseif (exist ("rows", "var"))
               ## Check if this axes is a subplot with the same layout and
               ## index as the requested one
               rcn = getappdata (child, "__subplotrcn__");
@@ -357,7 +357,7 @@ function h = subplot (varargin)
   end_unwind_protect
 
   if (nargout > 0)
-    h = hsubplot;
+    hax = hsubplot;
   endif
 
 endfunction
@@ -648,6 +648,18 @@ endfunction
 %!   delete (hf);
 %! end_unwind_protect
 
+## Mixed rcn and position mode
+%!test <*62526>
+%! hf = figure ("visible", "off");
+%! unwind_protect
+%!   h1 = subplot (2, 2, 1);
+%!   h2 = subplot ("position", [0.5 0.5 0.3 0.3]);
+%!   h3 = subplot (223);
+%!   assert (get (hf, "children"), [h3; h2; h1]);
+%! unwind_protect_cleanup
+%!   delete (hf);
+%! end_unwind_protect
+
 ## Align mode
 %!test
 %! hf = figure ("visible", "off");
