@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1996-2021 The Octave Project Developers
+## Copyright (C) 1996-2024 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,8 +24,8 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {} polyint (@var{p})
-## @deftypefnx {} {} polyint (@var{p}, @var{k})
+## @deftypefn  {} {@var{q} =} polyint (@var{p})
+## @deftypefnx {} {@var{q} =} polyint (@var{p}, @var{k})
 ## Return the coefficients of the integral of the polynomial whose
 ## coefficients are represented by the vector @var{p}.
 ##
@@ -34,9 +34,9 @@
 ## @seealso{polyder, polyval}
 ## @end deftypefn
 
-function retval = polyint (p, k)
+function q = polyint (p, k)
 
-  if (nargin < 1 || nargin > 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -53,7 +53,7 @@ function retval = polyint (p, k)
   lp = length (p);
 
   if (lp == 0)
-    retval = [];
+    q = [];
     return;
   endif
 
@@ -62,7 +62,7 @@ function retval = polyint (p, k)
     p = p.';
   endif
 
-  retval = [(p ./ [lp:-1:1]), k];
+  q = [(p ./ [lp:-1:1]), k];
 
 endfunction
 
@@ -79,5 +79,5 @@ endfunction
 %! B = [length(A):-1:1];
 %! assert (polyint (A), [1./B, 0]);
 
-%!error polyint ()
+%!error <Invalid call> polyint ()
 %!error polyint (ones (2,2))
