@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1997-2021 The Octave Project Developers
+## Copyright (C) 1997-2024 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,8 +24,8 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {} ifftshift (@var{x})
-## @deftypefnx {} {} ifftshift (@var{x}, @var{dim})
+## @deftypefn  {} {@var{x} =} ifftshift (@var{y})
+## @deftypefnx {} {@var{x} =} ifftshift (@var{y}, @var{dim})
 ## Undo the action of the @code{fftshift} function.
 ##
 ## For even length @var{x}, @code{fftshift} is its own inverse, but odd lengths
@@ -33,40 +33,40 @@
 ## @seealso{fftshift}
 ## @end deftypefn
 
-function retval = ifftshift (x, dim)
+function x = ifftshift (y, dim)
 
-  if (nargin != 1 && nargin != 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
-  if (! (isnumeric (x) || islogical (x) || ischar (x)))
-    error ("ifftshift: X must be a vector or matrix");
+  if (! (isnumeric (y) || islogical (y) || ischar (y)))
+    error ("ifftshift: Y must be a vector or matrix");
   endif
 
   if (nargin == 2)
     if (! (isscalar (dim) && dim > 0 && dim == fix (dim)))
       error ("ifftshift: dimension DIM must be a positive integer");
     endif
-    nd = ndims (x);
-    sz = size (x);
+    nd = ndims (y);
+    sz = size (y);
     sz2 = floor (sz(dim) / 2);
     idx = repmat ({':'}, nd, 1);
     idx{dim} = [sz2+1:sz(dim), 1:sz2];
-    retval = x(idx{:});
+    x = y(idx{:});
   else
-    if (isvector (x))
-      xl = length (x);
-      xx = floor (xl/2);
-      retval = x([xx+1:xl, 1:xx]);
+    if (isvector (y))
+      yl = length (y);
+      y2 = floor (yl/2);
+      x = y([y2+1:yl, 1:y2]);
     else
-      nd = ndims (x);
-      sz = size (x);
+      nd = ndims (y);
+      sz = size (y);
       sz2 = floor (sz ./ 2);
       idx = cell ();
       for i = 1:nd
         idx{i} = [sz2(i)+1:sz(i), 1:sz2(i)];
       endfor
-      retval = x(idx{:});
+      x = y(idx{:});
     endif
   endif
 
@@ -134,7 +134,6 @@ endfunction
 %! assert (ifftshift (y), x);
 
 ## Test input validation
-%!error ifftshift ()
-%!error ifftshift (1, 2, 3)
+%!error <Invalid call> ifftshift ()
 %!error ifftshift (0:3, -1)
 %!error ifftshift (0:3, 0:3)
